@@ -1,6 +1,8 @@
 package Bundle::ExCore::Perl5018;
 
-our $VERSION = '0.002';
+use strict;
+
+our $VERSION = '0.003';
 
 1;
 
@@ -20,8 +22,6 @@ Archive::Extract
 
 B::Lint
 
-B::Lint::Debug
-
 CPANPLUS
 
 Devel::InnerPackage
